/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.sinfo.common;

import java.io.Serializable;

import org.dive4elements.river.artifacts.sinfo.tkhcalculation.SoilKind;
import org.dive4elements.river.artifacts.sinfo.tkhcalculation.Tkh;

/**
 * Contains common result data of flow-depth- and tkh-calculations.
 *
 * @author Gernot Belger
 */
public abstract class AbstractSInfoResultRow implements Serializable {
    private static final long serialVersionUID = 1L;

    private final Tkh tkh;

    private final String waterlevelLabel;

    private final String gauge;

    private final String location;

    public AbstractSInfoResultRow(final Tkh tkh, final String waterlevelLabel, final String gauge, final String location) {
        this.tkh = tkh;
        this.waterlevelLabel = waterlevelLabel;
        this.gauge = gauge;
        this.location = location;
    }

    public final double getStation() {
        return this.tkh.getStation();
    }

    public final SoilKind getTkhKind() {
        return this.tkh.getKind();
    }

    public final double getTkh() {
        return this.tkh.getTkh();
    }

    public final double getTkhUp() {
        return this.tkh.getUp();
    }

    public final double getTkhDown() {
        return this.tkh.getDown();
    }

    public final double getWaterlevel() {
        return this.tkh.getWaterlevel();
    }

    public final double getDischarge() {
        return this.tkh.getDischarge();
    }

    public final String getWaterlevelLabel() {
        return this.waterlevelLabel;
    }

    public final String getGauge() {
        return this.gauge;
    }

    public final double getMeanBedHeight() {
        return this.tkh.getMeanBedHeight();
    }

    public final double getFlowDepth() {
        return this.tkh.getFlowDepth();
    }

    public double getFlowDepthWithTkh() {
        return this.tkh.getFlowDepthTkh();
    }

    public double getVelocity() {
        return this.tkh.getVelocity();
    }

    public double getD50() {
        return this.tkh.getD50();
    }

    public double getTau() {
        return this.tkh.getTau();
    }

    public final String getLocation() {
        return this.location;
    }
}